@@ -49,7 +49,7 @@ pub(super) mod function {
         objects: Find,
         progress: &mut dyn gix_features::progress::Progress,
         mut ctx: Context<'_>,
-        options: Options,
+        options: Options<'_>,
     ) -> Result<Outcome, Error>
     where
         T: Send + Clone,
@@ -195,7 +195,7 @@ pub(super) mod function {
                         if let Some(v) = entries_for_sorting.as_mut() {
                             v.push((change, location));
                         } else if let Some(change) = tracker.try_push_change(change, location.as_ref()) {
-                            collector.visit_entry(rewrite::change_to_entry(change, entries))
+                            collector.visit_entry(rewrite::change_to_entry(change, entries));
                         }
                     }
 
@@ -218,7 +218,7 @@ pub(super) mod function {
                                     if let Some(v) = entries_for_sorting.as_mut() {
                                         v.push(entry);
                                     } else {
-                                        collector.visit_entry(entry)
+                                        collector.visit_entry(entry);
                                     }
                                 }
                                 Some(src) => {
@@ -385,7 +385,7 @@ pub(super) mod function {
             pub(super) should_interrupt: &'a AtomicBool,
         }
 
-        impl<'index, 'a, T, U> gix_dir::walk::Delegate for Delegate<'index, 'a, T, U> {
+        impl<T, U> gix_dir::walk::Delegate for Delegate<'_, '_, T, U> {
             fn emit(&mut self, entry: EntryRef<'_>, collapsed_directory_status: Option<Status>) -> Action {
                 let entry = entry.to_owned();
                 self.tx.send(Event::DirEntry(entry, collapsed_directory_status)).ok();
@@ -404,6 +404,7 @@ pub(super) mod function {
         use crate::index_as_worktree_with_renames::{Entry, Error};
         use bstr::BStr;
         use gix_diff::rewrites::tracker::ChangeKind;
+        use gix_diff::tree::visit::Relation;
         use gix_dir::entry::Kind;
         use gix_filter::pipeline::convert::ToGitOutcome;
         use gix_hash::oid;
@@ -425,7 +426,7 @@ pub(super) mod function {
             },
         }
 
-        impl<'index, T, U> gix_diff::rewrites::tracker::Change for ModificationOrDirwalkEntry<'index, T, U>
+        impl<T, U> gix_diff::rewrites::tracker::Change for ModificationOrDirwalkEntry<'_, T, U>
         where
             T: Clone,
             U: Clone,
@@ -437,6 +438,12 @@ pub(super) mod function {
                 }
             }
 
+            fn relation(&self) -> Option<Relation> {
+                // TODO: figure out if index or worktree can provide containerization - worktree should be possible.
+                //       index would take some processing.
+                None
+            }
+
             fn kind(&self) -> ChangeKind {
                 match self {
                     ModificationOrDirwalkEntry::Modification(m) => match &m.status {
